############################################################################
#
# MODULE:     r.slope.stability - installation script
# AUTHOR(S):  Martin Mergili
#
# PURPOSE:    The slope stability model
#
# COPYRIGHT:  (C) 2009-2014 by the authors
#             (C) 1999-2014 by the GRASS Development Team
#
# VERSION:    20140425 (April 25, 2014)
#
#             This program is free software under the GNU General Public
#             License (>=v2). Read the file COPYING that comes with GRASS
#             for details.
#
############################################################################

pathmain=`pwd`

#PATHGRASS="/usr/local/grass-6.4.4svn/"
#PATHSOURCE="/usr/local/src/grass64_release/"

echo "Full path to GRASS source (slashes at beginning and end): "
read PATHSOURCE

echo "Full path to GRASS installation (slashes at beginning and end): "
read PATHGRASS

#INSTALLING PYTHON-BASED MODULES FOR DATA MANAGEMENT
#r.slope.stability.launch.py is installed as a module r.slope.stability

#Exporting parameters
export GISBASE="$PATHGRASS"
export PATH="$PATH:$GISBASE/bin:$GISBASE/scripts"
export LD_LIBRARY_PATH="$LD_LIBRARY_PATH:$GISBASE/lib"
export GIS_LOCK=$$
export GISRC="$HOME/.grassrc6"
export PYTHONPATH="$PYTHONPATH:$GISBASE/etc/python"

#Making python script executable
chmod +x r.slope.stability.py

#Removing directory with installation files, if existing
if [ -d "$PATHSOURCE"scripts/r.slope.stability ]
then
    rm -rf "$PATHSOURCE"scripts/r.slope.stability
fi

#Creating directory for installation files and copying r.slope.stability.py and r.slope.stability.html.py
mkdir "$PATHSOURCE"scripts/r.slope.stability
cp r.slope.stability.py "$PATHSOURCE"scripts/r.slope.stability/r.slope.stability
cp r.slope.stability.html "$PATHSOURCE"scripts/r.slope.stability/r.slope.stability.html

#Moving to the directory for installation files
cd "$PATHSOURCE"scripts/r.slope.stability

# Creating help file and makefile
touch r.slope.stability.html
echo "MODULE_TOPDIR = ../.." > Makefile
echo "" >> Makefile
echo "PGM = r.slope.stability" >> Makefile
echo "" >> Makefile
echo "include \$(MODULE_TOPDIR)/include/Make/Script.make" >> Makefile
echo "" >> Makefile
echo "default: script" >> Makefile

#Installing r.slope.stability
make
make install

cd $pathmain

#Exporting parameters
export GISBASE="$PATHGRASS"
export PATH="$PATH:$GISBASE/bin:$GISBASE/scripts"
export LD_LIBRARY_PATH="$LD_LIBRARY_PATH:$GISBASE/lib"
export GIS_LOCK=$$
export GISRC="$HOME/.grassrc6"
export PYTHONPATH="$PYTHONPATH:$GISBASE/etc/python"

#Making python script executable
chmod +x r.slope.stability.multicore.py

#Removing directory with installation files, if existing
if [ -d "$PATHSOURCE"scripts/r.slope.stability.multicore ]
then
    rm -rf "$PATHSOURCE"scripts/r.slope.stability.multicore
fi

#Creating directory for installation files, copying r.slope.stability.multicore.py and R scripts
mkdir "$PATHSOURCE"scripts/r.slope.stability.multicore
cp r.slope.stability.multicore.py "$PATHSOURCE"scripts/r.slope.stability.multicore/r.slope.stability.multicore
cp r.slope.stability.evolution.r "$PATHGRASS"scripts/r.slope.stability.evolution.r
cp r.slope.stability.map.r "$PATHGRASS"scripts/r.slope.stability.map.r
cp r.slope.stability.profile.r "$PATHGRASS"scripts/r.slope.stability.profile.r
cp r.slope.stability.rad.r "$PATHGRASS"scripts/r.slope.stability.rad.r
cp r.slope.stability.reg.r "$PATHGRASS"scripts/r.slope.stability.reg.r
cp r.slope.stability.roc.r "$PATHGRASS"scripts/r.slope.stability.roc.r

#Moving to the directory for installation files
cd "$PATHSOURCE"scripts/r.slope.stability.multicore

# Creating help file and makefile
touch r.slope.stability.multicore.html
echo "MODULE_TOPDIR = ../.." > Makefile
echo "" >> Makefile
echo "PGM = r.slope.stability.multicore" >> Makefile
echo "" >> Makefile
echo "include \$(MODULE_TOPDIR)/include/Make/Script.make" >> Makefile
echo "" >> Makefile
echo "default: script" >> Makefile

#Installing r.slope.stability.multicore
make
make install

echo ""
echo "Installation of r.slope.stability and r.slope.stability.multicore completed. Please check for possible error messages. "
echo "Press ENTER for proceeding with the installation of r.slope.stability.main. "
read answer

#Returning to initial directory
cd $pathmain
clear


#INSTALLING C-BASED MODULE FOR SLOPE STABILITY MODEL
#main.c is installed as a module r.slope.stability.main

#Removing directory with installation files, if existing
if [ -d "$PATHSOURCE"raster/r.slope.stability.main ]
then
    rm -rf "$PATHSOURCE"raster/r.slope.stability.main
fi

#Creating directory for installation files and copying main.c
mkdir "$PATHSOURCE"raster/r.slope.stability.main
cp r.slope.stability.main.c "$PATHSOURCE"raster/r.slope.stability.main/main.c

#Moving to the directory for installation files
cd "$PATHSOURCE"raster/r.slope.stability.main

# Creating makefile
echo "MODULE_TOPDIR = ../.." > Makefile
echo "" >> Makefile
echo "PGM = r.slope.stability.main" >> Makefile
echo "" >> Makefile
echo "LIBES = \$(GPROJDEP) \$(GISLIB) \$(SEGMENTLIB) \$(GMATHLIB)" >> Makefile
echo "DEPENDENCIES = \$(GPROJDEP) \$(GISDEP) \$(GMATHDEP)" >> Makefile
echo "EXTRA_INC = \$(PROJINC)" >> Makefile
echo "" >> Makefile
echo "include \$(MODULE_TOPDIR)/include/Make/Module.make" >> Makefile
echo "" >> Makefile
echo "default: cmd" >> Makefile

# Installing r.slope.stability.main
make
INST_NOW=y make

echo ""
echo "Installation of r.slope.stability.main completed. Please check for possible error messages. "
echo "Press ENTER for exit. "
read answer

#Returning to initial directory and terminating sudo mode
cd $pathmain
sudo -k
clear

